django-payments
===============

.. image:: https://jazzband.co/static/img/badge.svg
  :target: https://jazzband.co/
  :alt: Jazzband

.. image:: https://github.com/jazzband/django-payments/workflows/Test/badge.svg
   :target: https://github.com/jazzband/django-payments/actions
   :alt: GitHub Actions

.. image:: https://codecov.io/gh/jazzband/django-payments/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/jazzband/django-payments
  :alt: Build coverage

.. image:: https://readthedocs.org/projects/django-payments/badge/?version=latest
  :target: http://django-payments.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/django-payments.svg
  :target: https://pypi.python.org/pypi/django-payments
  :alt: version on pypi

.. image:: https://img.shields.io/pypi/dm/django-payments.svg
  :target: https://pypi.python.org/pypi/django-payments
  :alt: downloads

.. image:: https://img.shields.io/pypi/l/django-payments.svg
  :target: https://github.com/jazzband/django-payments/blob/master/LICENSE
  :alt: licence

Universal payment handling for Django

Documentation: https://django-payments.readthedocs.org/


Additional payment providers
----------------------------

* `BNL POSitivity (BNP Paribas) <https://github.com/esistgut/django-payments-bnlepos>`_
* `Redsys (formerly known as Sermepa) <https://github.com/ajostergaard/django-payments-redsys>`_
* `Razorpay <https://github.com/NyanKiyoshi/django-payments-razorpay/>`_
* `PayU <https://github.com/PetrDlouhy/django-payments-payu/>`_
